==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/item/compat/biomancy/BiologicalCircuitBoardItem.java <==
package net.tlotd.item.compat.biomancy;

import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2960;
import net.minecraft.class_437;

public class BiologicalCircuitBoardItem extends class_1792 {
    public BiologicalCircuitBoardItem(class_1793 settings) {
        super(settings);
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 MODS_FONT_ID = new class_2960("tlotd", "mods");
    public static final class_2960 CARO_INVITICA_FONT_ID = new class_2960("tlotd", "caro_invitica");

    @Override
    public class_2561 method_7864(class_1799 stack) {
        return class_2561.method_43471(this.method_7876()).method_27694(style -> style.method_36139(0xA58369));
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        tooltip.add(class_2561.method_43471("info.tlotd.not_yet_implemented").method_27692(class_124.field_1061));
        if (class_437.method_25442()) {
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_2").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_3").method_27692(class_124.field_1080));
        } else {
            class_2583 style = method_7848().method_10866();
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip").method_10862(style.method_27704(CARO_INVITICA_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_2").method_10862(style.method_27704(CARO_INVITICA_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_3").method_10862(style.method_27704(CARO_INVITICA_FONT_ID)).method_27692(class_124.field_1080));
        }
        if (context.method_47370()){
            tooltip.add(class_2561.method_43470("\uE013 ").method_10862(class_2583.field_24360.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.biomancy.name").method_10862(class_2583.field_24360.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            tooltip.add(class_2561.method_43470("\uE010 ").method_10862(class_2583.field_24360.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.spore.name").method_10862(class_2583.field_24360.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
        }
        super.method_7851(stack, world, tooltip, context);
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/item/compat/biomancy/BiologicalCircuitBoardItem.java <==
package net.tlotd.item.compat.biomancy;

import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2960;
import net.minecraft.class_437;

public class BiologicalCircuitBoardItem extends class_1792 {
    public BiologicalCircuitBoardItem(class_1793 settings) {
        super(settings);
    }

    public static final class_2960 DEFAULT_FONT_ID = new class_2960("minecraft", "default");
    public static final class_2960 MODS_FONT_ID = new class_2960("tlotd", "mods");
    public static final class_2960 CARO_INVITICA_FONT_ID = new class_2960("tlotd", "caro_invitica");

    @Override
    public class_2561 method_7864(class_1799 stack) {
        return class_2561.method_43471(this.method_7876()).method_27694(style -> style.method_36139(0xA58369));
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        tooltip.add(class_2561.method_43471("info.tlotd.not_yet_implemented").method_27692(class_124.field_1061));
        if (class_437.method_25442()) {
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_2").method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_3").method_27692(class_124.field_1080));
        } else {
            class_2583 style = method_7848().method_10866();
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip").method_10862(style.method_27704(CARO_INVITICA_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_2").method_10862(style.method_27704(CARO_INVITICA_FONT_ID)).method_27692(class_124.field_1080));
            tooltip.add(class_2561.method_43471("item.tlotd.biological_circuit_board.tooltip_3").method_10862(style.method_27704(CARO_INVITICA_FONT_ID)).method_27692(class_124.field_1080));
        }
        if (context.method_47370()){
            tooltip.add(class_2561.method_43470("\uE013 ").method_10862(class_2583.field_24360.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.biomancy.name").method_10862(class_2583.field_24360.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            tooltip.add(class_2561.method_43470("\uE010 ").method_10862(class_2583.field_24360.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.spore.name").method_10862(class_2583.field_24360.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
            tooltip.add(class_2561.method_43470("\uE014 ").method_10862(class_2583.field_24360.method_27704(MODS_FONT_ID)).method_10852(class_2561.method_43471("mod.neepmeat.name").method_10862(class_2583.field_24360.method_27704(DEFAULT_FONT_ID).method_27706(class_124.field_1080))));
        }
        super.method_7851(stack, world, tooltip, context);
    }
}
